// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot.commands;

import java.util.Map;
import java.util.function.DoubleSupplier;

import edu.wpi.first.networktables.NetworkTableEntry;
import edu.wpi.first.wpilibj.shuffleboard.BuiltInWidgets;
import edu.wpi.first.wpilibj.shuffleboard.Shuffleboard;
import edu.wpi.first.wpilibj.shuffleboard.ShuffleboardTab;
import edu.wpi.first.wpilibj2.command.CommandBase;
import frc.robot.subsystems.DriveTrain;

public class Drive extends CommandBase {

  private final DriveTrain driveTrain;
  private final DoubleSupplier speed;
  private final DoubleSupplier rotation;

  private final ShuffleboardTab tab = Shuffleboard.getTab("Peanut");
  private final NetworkTableEntry maxSpeed = tab.addPersistent("Max Speed", 0.5)
    .withWidget(BuiltInWidgets.kNumberSlider)
    .withSize(2, 1)
    .withProperties(Map.of("min", 0, "max", 1))
    .getEntry();

  /** Creates a new Drive. */
  public Drive(DriveTrain driveTrain, DoubleSupplier speed, DoubleSupplier rotation) {
    this.driveTrain = driveTrain;
    this.speed = speed;
    this.rotation = rotation;
    // Use addRequirements() here to declare subsystem dependencies.
    addRequirements(driveTrain);
  }

  // Called when the command is initially scheduled.
  @Override
  public void initialize() {}

  // Called every time the scheduler runs while the command is scheduled.
  @Override
  public void execute() {
    double max = maxSpeed.getDouble(0.5);
    double spd = speed.getAsDouble() * max;
    double rot = rotation.getAsDouble() * max;
    
    driveTrain.arcadeDrive(spd, rot);
  }

  // Called once the command ends or is interrupted.
  @Override
  public void end(boolean interrupted) {}

  // Returns true when the command should end.
  @Override
  public boolean isFinished() {
    return false;
  }
}
